@@ -17,14 +17,15 @@ package PostScript::Report::Builder;
 # ABSTRACT: Build a PostScript::Report object
 #---------------------------------------------------------------------
 
-our $VERSION = '0.11';
-# This file is part of PostScript-Report 0.12 (May 4, 2013)
+our $VERSION = '0.13';
+# This file is part of PostScript-Report 0.13 (November 30, 2013)
 
 use 5.008;
 use Moose;
 use MooseX::Types::Moose qw(Bool HashRef Int Str);
 use PostScript::Report::Types ':all';
 
+use Module::Runtime qw( require_module );
 use PostScript::Report::HBox ();
 use PostScript::Report::VBox ();
 use String::RewritePrefix ();
@@ -408,9 +409,7 @@ sub require_class
   my ($self, $class) = @_;
 
   return if $loaded_class{$class};
-
-  die "Invalid class name $class" unless $class =~ /^[:_A-Z0-9]+$/i;
-  eval "require $class;" or die "Unable to load $class: $@";
+  require_module($class);
 
   $loaded_class{$class} = 1;
 } # end require_class
@@ -430,9 +429,9 @@ PostScript::Report::Builder - Build a PostScript::Report object
 
 =head1 VERSION
 
-This document describes version 0.11 of
-PostScript::Report::Builder, released May 4, 2013
-as part of PostScript-Report version 0.12.
+This document describes version 0.13 of
+PostScript::Report::Builder, released November 30, 2013
+as part of PostScript-Report version 0.13.
 
 =head1 SYNOPSIS
 
@@ -691,7 +690,7 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
-L<< http://github.com/madsen/postscript-report >>.
+L<< https://github.com/madsen/postscript-report >>.
 
 =head1 ACKNOWLEDGMENTS
 
