@@ -80,8 +80,8 @@ PostScript::Report::Font - Represents a PostScript font
 =head1 VERSION
 
 This document describes version 0.06 of
-PostScript::Report::Font, released May 4, 2013
-as part of PostScript-Report version 0.12.
+PostScript::Report::Font, released November 30, 2013
+as part of PostScript-Report version 0.13.
 
 =head1 DESCRIPTION
 
@@ -154,7 +154,7 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
-L<< http://github.com/madsen/postscript-report >>.
+L<< https://github.com/madsen/postscript-report >>.
 
 =head1 ACKNOWLEDGMENTS
 
