@@ -18,7 +18,7 @@ package PostScript::Report::LinkField;
 #---------------------------------------------------------------------
 
 our $VERSION = '0.10';
-# This file is part of PostScript-Report 0.12 (May 4, 2013)
+# This file is part of PostScript-Report 0.13 (November 30, 2013)
 
 use Moose;
 use MooseX::Types::Moose qw(Bool Int Num Str);
@@ -254,8 +254,8 @@ PostScript::Report::LinkField - A field that can contain hyperlinks
 =head1 VERSION
 
 This document describes version 0.10 of
-PostScript::Report::LinkField, released May 4, 2013
-as part of PostScript-Report version 0.12.
+PostScript::Report::LinkField, released November 30, 2013
+as part of PostScript-Report version 0.13.
 
 =head1 DESCRIPTION
 
@@ -331,7 +331,7 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
-L<< http://github.com/madsen/postscript-report >>.
+L<< https://github.com/madsen/postscript-report >>.
 
 =head1 ACKNOWLEDGMENTS
 
